==> Products.ThemeCentre-1.1.zip: Products.ThemeCentre-1.1/Products/ThemeCentre/catalog.py <==
from zope.app.component.interface import interfaceToName
from zope.component.exceptions import ComponentLookupError
from zope.interface import providedBy
from eea.themecentre.interfaces import IThemeTagging
from eea.mediacentre.interfaces import IMediaType
from Products.CMFCore.utils import getToolByName

def getSynonyms(portal):
    # used to return true synonyms
    vocabularies = getToolByName(portal, 'portal_vocabularies')
    root = getattr(vocabularies, 'themesmerged', None)
    synonyms = {}

    for secondLevel in root.objectValues():
        synonymous_themes = secondLevel.objectIds()
        for index, theme in enumerate(synonymous_themes):
            synonyms[theme] = synonymous_themes[:index] + synonymous_themes[index+1:]

    return synonyms

def getThemesForIndex(object, portal, **kwargs):
    try:
        themes = IThemeTagging(object)
        return themes.tags
    except (ComponentLookupError, TypeError, ValueError):
        # if can't be adapted, see if it's an AT object with getThemes method
        if hasattr(object, 'getThemes'):
            return object.getThemes()

        # The catalog expects AttributeErrors when a value can't be found
        raise AttributeError

def getInterfaces(object, portal, **kwargs):
    return [i.__identifier__ for i in providedBy(object).flattened()]

def getMediaTypes(object, portal, **kwargs):
    try:
        adapter = IMediaType(object)
        return adapter.types
    except (ComponentLookupError, TypeError, ValueError):
        raise AttributeError

==> Products.ThemeCentre-1.4.zip: Products.ThemeCentre-1.4/Products/ThemeCentre/catalog.py <==
#from zope.app.component.interface import interfaceToName
from zope.component.exceptions import ComponentLookupError
from zope.interface import providedBy
from eea.themecentre.interfaces import IThemeTagging
from eea.mediacentre.interfaces import IMediaType
from Products.CMFCore.utils import getToolByName

def getSynonyms(portal):
    # used to return true synonyms
    vocabularies = getToolByName(portal, 'portal_vocabularies')
    root = getattr(vocabularies, 'themesmerged', None)
    synonyms = {}

    for secondLevel in root.objectValues():
        synonymous_themes = secondLevel.objectIds()
        for index, theme in enumerate(synonymous_themes):
            synonyms[theme] = synonymous_themes[:index] + synonymous_themes[index+1:]

    return synonyms

def getThemesForIndex(obj, portal, **kwargs):
    try:
        themes = IThemeTagging(obj)
        return themes.tags
    except (ComponentLookupError, TypeError, ValueError):
        # if can't be adapted, see if it's an AT object with getThemes method
        if hasattr(obj, 'getThemes'):
            return obj.getThemes()

        # The catalog expects AttributeErrors when a value can't be found
        raise AttributeError

def getInterfaces(obj, portal, **kwargs):
    return [i.__identifier__ for i in providedBy(obj).flattened()]

def getMediaTypes(obj, portal, **kwargs):
    try:
        adapter = IMediaType(obj)
        return adapter.types
    except (ComponentLookupError, TypeError, ValueError):
        raise AttributeError
